@@ -1,3 +1,5 @@
+import os
+import signal
 import subprocess
 from datetime import datetime, timedelta, time
 from time import sleep
@@ -96,11 +98,11 @@ class Flux(object):
             if info:
                 print(f"{current.strftime('%Y-%m-%d %H:%M:%S')} flux running ---> ^_^ ")
             if p is None and status:
-                p = subprocess.Popen(self.os_command, shell=False)
+                p = subprocess.Popen(self.os_command, shell=True, close_fds=True, preexec_fn=os.setsid)
                 print("===> program start successful")
             if not status and p is not None:
                 print("Kill Program ", p.pid)
-                p.kill()
+                os.killpg(p.pid, signal.SIGUSR1)
                 p = None
             sleep(1)
 
